==> haskell-httpd-shed-0.4.1.1-421-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 httpd-shed
version:              0.4.1.1
visibility:           public
id:                   httpd-shed-0.4.1.1-IqIxMX3ffB93mbSvIYH2Gw
key:                  httpd-shed-0.4.1.1-IqIxMX3ffB93mbSvIYH2Gw
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  b8bd8372720ef66ebe8bddff78329d8f
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-9.0.2/site-local/httpd-shed-0.4.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/httpd-shed-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-httpd-shed
hs-libraries:         HShttpd-shed-0.4.1.1-IqIxMX3ffB93mbSvIYH2Gw
depends:
    base-4.15.1.0 network-3.1.2.7-KHsxGS10v7SFpM3TUBfkXY
    network-bsd-2.8.1.0-KfFyxJUMcGTIGspIKC1ucJ
    network-uri-2.6.4.1-6ZiP9eTaRPdCx8mZK7nGmp

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-httpd-shed-0.4.1.1-424-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 httpd-shed
version:              0.4.1.1
visibility:           public
id:                   httpd-shed-0.4.1.1-CklsDLYPZy04ujAutQsmkF
key:                  httpd-shed-0.4.1.1-CklsDLYPZy04ujAutQsmkF
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  a26253409870fa88c1beb30b2b08e6ce
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-9.0.2/site-local/httpd-shed-0.4.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/httpd-shed-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-httpd-shed
hs-libraries:         HShttpd-shed-0.4.1.1-CklsDLYPZy04ujAutQsmkF
depends:
    base-4.15.1.0 network-3.1.2.7-CYWaC4XvHgd3jC4vMNSEt4
    network-bsd-2.8.1.0-JQpTqO3tfV8D9KaYbTf3Jc
    network-uri-2.6.4.2-Bqno6giiEJ72xMDyBU05Tf

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
